searchData={"items":[{"type":"module","title":"Codepagex","doc":"Codepagex is an  elixir library to convert between string encodings to and from\nutf-8. Like iconv, but written in pure Elixir.\n\nAll the encodings are fetched from unicode.org tables and conversion functions\nare generated from these at compile time.","ref":"Codepagex.html"},{"type":"module","title":"Note on the unicode built in module - Codepagex","doc":"Note that the Erlang built in\n[`:unicode` module](http://erlang.org/doc/man/unicode.html#characters_to_binary-1)\nhas some provisions for converting between utf-8 and latin1 code sets. If that\nis all you need, you should consider not using `codepagex` but rather rely on this\nsimpler alternative.\n\nCompared to this functionality `codepagex` provides:\n\n* More codepage mapping options\n* The ability to handle illegal encoding with custom logic\n* A simpler interface\n\nBut please remember that `codepagex` is comparatively a lot more complex, making\nextensive use of macro programming.","ref":"Codepagex.html#module-note-on-the-unicode-built-in-module"},{"type":"module","title":"Examples - Codepagex","doc":"The package is assumed to be interfaced using only the `Codepagex` module.\n\n    iex> from_string(\"æøåÆØÅ\", :iso_8859_1)\n    {:ok, <<230, 248, 229, 198, 216, 197>>}\n\n    iex> to_string(<<230, 248, 229, 198, 216, 197>>, :iso_8859_1)\n    {:ok, \"æøåÆØÅ\"}\n\n    iex> from_string!(\"æøåÆØÅ\", :iso_8859_1)\n    <<230, 248, 229, 198, 216, 197>>\n\n    iex> to_string!(<<230, 248, 229, 198, 216, 197>>, :iso_8859_1)\n    \"æøåÆØÅ\"\n\nWhen there are invalid byte sequences in a String or encoded binary, the\nfunctions will not succeed. If you still want to handle these strings, you may\nspecify a function to handle these circumstances. Eg:\n\n    iex> from_string(\"Hello æøå!\", :ascii, replace_nonexistent(\"_\"))\n    {:ok, \"Hello ___!\", 3}\n\n    iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> to_string!(iso, :ascii, use_utf_replacement())\n    \"Hello ���!\"","ref":"Codepagex.html#module-examples"},{"type":"module","title":"Encodings - Codepagex","doc":"A full list of encodings is found by running `encoding_list/1`. \n\nThe encodings are best supplied as an atom, or else the string is converted to\natom for you (but with a somewhat less efficient function lookup). Eg:\n\n    iex> from_string(\"æøå\", \"ISO8859/8859-9\")\n    {:ok, <<230, 248, 229>>}\n\n    iex> from_string(\"æøå\", :\"ISO8859/8859-9\")\n    {:ok, <<230, 248, 229>>}\n\nFor some encodings, an alias is set up for easier dispatch. The list of aliases\nis found by running `aliases/1`. The code looks like: \n\n    iex> from_string!(\"Hello æøåÆØÅ!\", :iso_8859_1)\n    <<72, 101, 108, 108, 111, 32, 230, 248, 229, 198, 216, 197, 33>>","ref":"Codepagex.html#module-encodings"},{"type":"module","title":"Encoding selection - Codepagex","doc":"By default all ISO-8859 encodings and ASCII is included. There are a few more\navailable, and these must be specified in the `config/config.exs` file. The\nspecified files are then compiled. Adding many encodings may affect compilation\ntimes, in particular for the largest ones.\n\nTo specify the encodings to use, add the following lines to your\n`config/config.exs` and recompile:\n\n    use Mix.Config\n    config :codepagex, :encodings, [:ascii]\n\nThis will add only the ASCII encoding, as specified by it's shorthand alias.\nAny number of encodings may be specified like this in the list. The list may\ncontain strings, atoms or regular expressions that match either an alias or a\nfull encoding name, eg:\n\n    use Mix.Config\n    config :codepagex, :encodings, [\n      :ascii,           # by alias name\n      ~r[iso8859]i,     # by a regex matching the full name\n      \"ETSI/GSM0338\",   # by the full name as a string\n      :\"MISC/CP856\"     # by a full name as an atom\n    ]\n\nAfter modifying the encodings list in the configuration, always make sure to run the following or the encodings you specified will not be compiled in:\n\nmix deps.compile codepagex --force\n\nThis is necessary due to the fact that `Codepagex`'s configuration changes are not picked up automatically when it's a dependency in another project. Credit for the find goes to @michalmuskala here: https://elixirforum.com/t/sharing-with-the-community-text-transcoding-libraries/17962/2\n\nThe encodings that are known to require very long compile times are:\n\n- VENDORS/MISC/KPS9566\n- VENDORS/MICSFT/WINDOWS/CP932\n- VENDORS/MICSFT/WINDOWS/CP936\n- VENDORS/MICSFT/WINDOWS/CP949\n- VENDORS/MICSFT/WINDOWS/CP950","ref":"Codepagex.html#module-encoding-selection"},{"type":"module","title":"TODO - Codepagex","doc":"- A few encodings are not yet supported for different reasons. In particular\n  the asian and arab ones with left-right and up-down variations.\n- Test Elixir function specs\n- Benchmarking vs `iconv` native libraries\n- Support for iolists\n- when converting sections of a string that are unchanged, return the original\n  input. Consider using iolists to return the values so that chunks may be\n  saved continuously\n- lazy converter to get n characters / codepoints\n- function to drop n characters and take n characters (and slice?)","ref":"Codepagex.html#module-todo"},{"type":"function","title":"Codepagex.aliases/1","doc":"Returns a list of shorthand aliases that may be used instead of the full name\nof the encoding.\n\nThe available aliases are:\n\n| Alias | Full name |\n|------:|:----------|\n  | :ascii          | VENDORS/MISC/US-ASCII-QUOTES |\n  | :iso_8859_1     | ISO8859/8859-1 |\n  | :iso_8859_2     | ISO8859/8859-2 |\n  | :iso_8859_3     | ISO8859/8859-3 |\n  | :iso_8859_4     | ISO8859/8859-4 |\n  | :iso_8859_5     | ISO8859/8859-5 |\n  | :iso_8859_6     | ISO8859/8859-6 |\n  | :iso_8859_7     | ISO8859/8859-7 |\n  | :iso_8859_8     | ISO8859/8859-8 |\n  | :iso_8859_9     | ISO8859/8859-9 |\n  | :iso_8859_10    | ISO8859/8859-10 |\n  | :iso_8859_11    | ISO8859/8859-11 |\n  | :iso_8859_12    | ISO8859/8859-12 |\n  | :iso_8859_13    | ISO8859/8859-13 |\n  | :iso_8859_14    | ISO8859/8859-14 |\n  | :iso_8859_15    | ISO8859/8859-15 |\n  | :iso_8859_16    | ISO8859/8859-16 |\n\nSome of these may not be available depending on mix configuration. If the\n`selection` parameter is `:all` then all possible aliases are listed,\notherwise, only the available aliases are listed\n\nFor a full list of encodings, see `encoding_list/1`","ref":"Codepagex.html#aliases/1"},{"type":"function","title":"Codepagex.encoding_list/1","doc":"Returns a list of the supported encodings. These are extracted from\nhttp://unicode.org/ and the names correspond to a encoding file on that page\n\n`encoding_list/1` is normally called without any parameters to list the\nencodings that are currently configured during compilation. To see all\navailable options, even those unavailable, use `encoding_list(:all)`\n\nThe available encodings are:\n\n| ETSI/GSM0338                   | ISO8859/8859-1                 | ISO8859/8859-10                |\n| ISO8859/8859-11                | ISO8859/8859-13                | ISO8859/8859-14                |\n| ISO8859/8859-15                | ISO8859/8859-16                | ISO8859/8859-2                 |\n| ISO8859/8859-3                 | ISO8859/8859-4                 | ISO8859/8859-5                 |\n| ISO8859/8859-6                 | ISO8859/8859-7                 | ISO8859/8859-8                 |\n| ISO8859/8859-9                 | VENDORS/MICSFT/EBCDIC/CP037    | VENDORS/MICSFT/EBCDIC/CP1026   |\n| VENDORS/MICSFT/EBCDIC/CP500    | VENDORS/MICSFT/MAC/CYRILLIC    | VENDORS/MICSFT/MAC/GREEK       |\n| VENDORS/MICSFT/MAC/ICELAND     | VENDORS/MICSFT/MAC/LATIN2      | VENDORS/MICSFT/MAC/ROMAN       |\n| VENDORS/MICSFT/MAC/TURKISH     | VENDORS/MICSFT/PC/CP437        | VENDORS/MICSFT/PC/CP737        |\n| VENDORS/MICSFT/PC/CP775        | VENDORS/MICSFT/PC/CP850        | VENDORS/MICSFT/PC/CP852        |\n| VENDORS/MICSFT/PC/CP855        | VENDORS/MICSFT/PC/CP857        | VENDORS/MICSFT/PC/CP860        |\n| VENDORS/MICSFT/PC/CP861        | VENDORS/MICSFT/PC/CP862        | VENDORS/MICSFT/PC/CP863        |\n| VENDORS/MICSFT/PC/CP864        | VENDORS/MICSFT/PC/CP865        | VENDORS/MICSFT/PC/CP866        |\n| VENDORS/MICSFT/PC/CP869        | VENDORS/MICSFT/PC/CP874        | VENDORS/MICSFT/WINDOWS/CP1250  |\n| VENDORS/MICSFT/WINDOWS/CP1251  | VENDORS/MICSFT/WINDOWS/CP1252  | VENDORS/MICSFT/WINDOWS/CP1253  |\n| VENDORS/MICSFT/WINDOWS/CP1254  | VENDORS/MICSFT/WINDOWS/CP1255  | VENDORS/MICSFT/WINDOWS/CP1256  |\n| VENDORS/MICSFT/WINDOWS/CP1257  | VENDORS/MICSFT/WINDOWS/CP1258  | VENDORS/MICSFT/WINDOWS/CP874   |\n| VENDORS/MICSFT/WINDOWS/CP932   | VENDORS/MICSFT/WINDOWS/CP936   | VENDORS/MICSFT/WINDOWS/CP949   |\n| VENDORS/MICSFT/WINDOWS/CP950   | VENDORS/MISC/ATARIST           | VENDORS/MISC/CP424             |\n| VENDORS/MISC/CP856             | VENDORS/MISC/KOI8-R            | VENDORS/MISC/KOI8-U            |\n| VENDORS/MISC/KPS9566           | VENDORS/MISC/KZ1048            | VENDORS/MISC/US-ASCII-QUOTES   |\n\nFor more information about configuring encodings, refer to `Codepagex`.\n\nFor a list of shorthand names, see `aliases/1`","ref":"Codepagex.html#encoding_list/1"},{"type":"function","title":"Codepagex.from_string/2","doc":"Converts an Elixir string in utf-8 encoding to a binary in another encoding.\n\nThe `encoding` parameter should be in `encoding_list/0` as an atom or String,\nor in `aliases/0`.","ref":"Codepagex.html#from_string/2"},{"type":"function","title":"Examples - Codepagex.from_string/2","doc":"iex> from_string(\"HÉ¦¦Ó\", :iso_8859_1)\n    {:ok, <<72, 201, 166, 166, 211>>}\n\n    iex> from_string(\"HÉ¦¦Ó\", :\"ISO8859/8859-1\") # without alias\n    {:ok, <<72, 201, 166, 166, 211>>}\n\n    iex> from_string(\"ʒ\", :iso_8859_1)\n    {:error, \"Invalid bytes for encoding\"}","ref":"Codepagex.html#from_string/2-examples"},{"type":"function","title":"Codepagex.from_string/4","doc":"Convert an Elixir String in utf-8 to a binary in a specified encoding. A\nfunction parameter specifies how to deal with codepoints that are not\nrepresentable in the target encoding.\n\nCompared to `from_string/2`, you may pass a `missing_fun` function parameter\nto handle encoding errors in `string`. The function `replace_nonexistent/1`\nmay be used as a default error handling mechanism.\n\nThe `encoding` parameter should be in `encoding_list/0` as an atom or String,\nor in `aliases/0`.","ref":"Codepagex.html#from_string/4"},{"type":"function","title":"Implementing missing_fun - Codepagex.from_string/4","doc":"The `missing_fun` must be an anonymous function that returns a second\nfunction. The outer function will receive the encoding used by\n`from_string/4`, and must then return `{:ok, inner_function}` or `{:error,\nreason}`. Returning `:error` will cause `from_string/4` to fail.\n\nThe returned inner function must receive two arguments.\n\n- a String containing the remainder of the `string` parameter that is still\n  unprocessed.\n- the accumulator `acc`\n\nThe return value must be\n\n- `{:ok, replacement, new_rest, new_acc}` to continue processing\n- `{:error, reason, new_acc}` to cause `from_string/4` to fail\n\nThe `acc` parameter from `from_string/4` is passed between every invocation\nof the inner function then returned by `to_string/4`. In many use cases,\n`acc` may be ignored.","ref":"Codepagex.html#from_string/4-implementing-missing_fun"},{"type":"function","title":"Examples - Codepagex.from_string/4","doc":"Using the `replace_nonexistent/1` function to handle invalid bytes:\n\n    iex> from_string(\"Hello æøå!\", :ascii, replace_nonexistent(\"_\"))\n    {:ok, \"Hello ___!\", 3}\n\nDefining a custom `missing_fun`:\n\n    iex> missing_fun =\n    ...>   fn encoding ->\n    ...>     case from_string(\"#\", encoding) do\n    ...>       {:ok, replacement} ->\n    ...>         inner_fun =\n    ...>           fn <<_ :: utf8, rest :: binary>>, acc ->\n    ...>             {:ok, replacement, rest, acc + 1}\n    ...>           end\n    ...>         {:ok, inner_fun}\n    ...>       err ->\n    ...>         err\n    ...>     end\n    ...>   end\n    iex> from_string(\"Hello æøå!\", :ascii, missing_fun, 0)\n    {:ok, \"Hello ###!\", 3}\n\nThe previous code was included for completeness. If you know your replacement\nis valid in the target encoding, you might as well do:\n\n    iex> missing_fun = fn _encoding ->\n    ...>   inner_fun =\n    ...>     fn <<_ :: utf8, rest :: binary>>, acc ->\n    ...>       {:ok, \"#\", rest, acc + 1}\n    ...>     end\n    ...>   {:ok, inner_fun}\n    ...> end\n    iex> from_string(\"Hello æøå!\", :ascii, missing_fun, 10)\n    {:ok, \"Hello ###!\", 13}","ref":"Codepagex.html#from_string/4-examples"},{"type":"function","title":"Codepagex.from_string!/2","doc":"Like `from_string/2` but raising exceptions on errors.","ref":"Codepagex.html#from_string!/2"},{"type":"function","title":"Examples - Codepagex.from_string!/2","doc":"iex> from_string!(\"HÉ¦¦Ó\", :iso_8859_1)\n    <<72, 201, 166, 166, 211>>\n\n    iex> from_string!(\"ʒ\", :iso_8859_1)\n    ** (Codepagex.Error) Invalid bytes for encoding","ref":"Codepagex.html#from_string!/2-examples"},{"type":"function","title":"Codepagex.from_string!/4","doc":"Like `from_string/4` but raising exceptions on errors.","ref":"Codepagex.html#from_string!/4"},{"type":"function","title":"Examples - Codepagex.from_string!/4","doc":"iex> missing_fun = replace_nonexistent(\"_\")\n    iex> from_string!(\"Hello æøå!\", :ascii, missing_fun)\n    \"Hello ___!\"","ref":"Codepagex.html#from_string!/4-examples"},{"type":"function","title":"Codepagex.load_atoms/0","doc":"","ref":"Codepagex.html#load_atoms/0"},{"type":"function","title":"Codepagex.replace_nonexistent/1","doc":"This function may be used in conjunction with to `from_string/4` or\n`from_string!/4`. If there are utf-8 codepoints in the source string that are\nnot possible to represent in the target encoding, they are replaced with a\nString.\n\nWhen using this function, `from_string/4` will never return an error if\n`replace_with` converts to the target encoding without errors.\n\n\nThe accumulator input `acc` of `from_string/4` is incremented on each\nreplacement done.","ref":"Codepagex.html#replace_nonexistent/1"},{"type":"function","title":"Examples - Codepagex.replace_nonexistent/1","doc":"iex> from_string!(\"Hello æøå!\", :ascii, replace_nonexistent(\"_\"))\n    \"Hello ___!\"\n\n    iex> from_string(\"Hello æøå!\", :ascii, replace_nonexistent(\"_\"), 100)\n    {:ok, \"Hello ___!\", 103}","ref":"Codepagex.html#replace_nonexistent/1-examples"},{"type":"function","title":"Codepagex.to_string/2","doc":"Converts a binary in a specified encoding to an Elixir string in utf-8\nencoding.\n\nThe encoding parameter should be in `encoding_list/0` (passed as atoms or\nstrings), or in `aliases/0`.","ref":"Codepagex.html#to_string/2"},{"type":"function","title":"Examples - Codepagex.to_string/2","doc":"iex> to_string(<<72, 201, 166, 166, 211>>, :iso_8859_1)\n    {:ok, \"HÉ¦¦Ó\"}\n\n    iex> to_string(<<128>>, \"ETSI/GSM0338\")\n    {:error, \"Invalid bytes for encoding\"}","ref":"Codepagex.html#to_string/2-examples"},{"type":"function","title":"Codepagex.to_string/4","doc":"Convert a binary in a specified encoding into an Elixir string in utf-8\nencoding\n\nCompared to `to_string/2`, you may pass a `missing_fun` function parameter to\nhandle encoding errors in the `binary`.  The function `use_utf_replacement/0`\nmay be used as a default error handling mechanism.","ref":"Codepagex.html#to_string/4"},{"type":"function","title":"Implementing missing_fun - Codepagex.to_string/4","doc":"The `missing_fun` must be an anonymous function that returns a second\nfunction. The outer function will receive the encoding used by `to_string/4`,\nand must then return `{:ok, inner_function}` or `{:error, reason}`. Returning\n`:error` will cause `to_string/4` to fail.\n\nThe returned inner function must receive two arguments.\n\n- a binary containing the remainder of the `binary` parameter that is still\n  unprocessed.\n- the accumulator `acc`\n\nThe return value must be\n\n- `{:ok, replacement, new_rest, new_acc}` to continue processing\n- `{:error, reason, new_acc}` to cause `to_string/4` to fail\n\nThe `acc` parameter from `to_string/4` is passed between every invocation of\nthe inner function then returned by `to_string/4`. In many use cases, `acc`\nmay be ignored.","ref":"Codepagex.html#to_string/4-implementing-missing_fun"},{"type":"function","title":"Examples - Codepagex.to_string/4","doc":"Using the `use_utf_replacement/0` function to handle invalid bytes:\n\n    iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> to_string(iso, :ascii, use_utf_replacement())\n    {:ok, \"Hello ���!\", 3}\n\n    iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> missing_fun =\n    ...>   fn encoding ->\n    ...>     case to_string(\"#\", encoding) do\n    ...>       {:ok, replacement} ->\n    ...>         inner_fun =\n    ...>           fn <<_, rest :: binary>>, acc ->\n    ...>             {:ok, replacement, rest, acc + 1}\n    ...>           end\n    ...>         {:ok, inner_fun}\n    ...>       err ->\n    ...>         err\n    ...>     end\n    ...>   end\n    iex> to_string(iso, :ascii, missing_fun, 0)\n    {:ok, \"Hello ###!\", 3}\n\nThe previous code was included for completeness. If you know your replacement\nis valid in the target encoding, you might as well do:\n\n    iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> missing_fun =\n    ...>   fn _encoding ->\n    ...>     inner_fun =\n    ...>       fn <<_, rest :: binary>>, acc ->\n    ...>         {:ok, \"#\", rest, acc + 1}\n    ...>       end\n    ...>     {:ok, inner_fun}\n    ...>   end\n    iex> to_string(iso, :ascii, missing_fun, 10)\n    {:ok, \"Hello ###!\", 13}","ref":"Codepagex.html#to_string/4-examples"},{"type":"function","title":"Codepagex.to_string!/2","doc":"Like `to_string/2` but raises exceptions on errors.","ref":"Codepagex.html#to_string!/2"},{"type":"function","title":"Examples - Codepagex.to_string!/2","doc":"iex> to_string!(<<72, 201, 166, 166, 211>>, :iso_8859_1)\n    \"HÉ¦¦Ó\"\n\n    iex> to_string!(<<128>>, \"ETSI/GSM0338\")\n    ** (Codepagex.Error) Invalid bytes for encoding","ref":"Codepagex.html#to_string!/2-examples"},{"type":"function","title":"Codepagex.to_string!/4","doc":"Like `to_string/4` but raises exceptions on errors.","ref":"Codepagex.html#to_string!/4"},{"type":"function","title":"Examples - Codepagex.to_string!/4","doc":"iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> to_string!(iso, :ascii, use_utf_replacement())\n    \"Hello ���!\"","ref":"Codepagex.html#to_string!/4-examples"},{"type":"function","title":"Codepagex.translate/3","doc":"Convert a binary in one encoding to a binary in another encoding. The string\nis converted to utf-8 internally in the process.\n\nThe encoding parameters should be in `encoding_list/0` or `aliases/0`. It may\nbe passed as an atom, or a string for full encoding names.","ref":"Codepagex.html#translate/3"},{"type":"function","title":"Examples - Codepagex.translate/3","doc":"iex> translate(<<174>>, :iso_8859_1, :iso_8859_15)\n    {:ok, <<174>>}\n\n    iex> translate(<<174>>, :iso_8859_1, :iso_8859_2)\n    {:error, \"Invalid bytes for encoding\"}","ref":"Codepagex.html#translate/3-examples"},{"type":"function","title":"Codepagex.translate!/3","doc":"Like `translate/3` but raises exceptions on errors","ref":"Codepagex.html#translate!/3"},{"type":"function","title":"Examples - Codepagex.translate!/3","doc":"iex> translate!(<<174>>, :iso_8859_1, :iso_8859_15)\n    <<174>>\n\n    iex> translate!(<<174>>, :iso_8859_1,:iso_8859_2)\n    ** (Codepagex.Error) Invalid bytes for encoding","ref":"Codepagex.html#translate!/3-examples"},{"type":"function","title":"Codepagex.use_utf_replacement/0","doc":"This function may be used as a parameter to `to_string/4` or `to_string!/4`\nsuch that any bytes in the input binary that don't have a proper encoding are\nreplaced with a special unicode character and the function will not\nfail.\n\nIf this function is used, `to_string/4` will never return an error.\n\nThe accumulator input `acc` of `to_string/4` is incremented by the number of\nreplacements made.","ref":"Codepagex.html#use_utf_replacement/0"},{"type":"function","title":"Examples - Codepagex.use_utf_replacement/0","doc":"iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> to_string!(iso, :ascii, use_utf_replacement())\n    \"Hello ���!\"\n\n    iex> iso = \"Hello æøå!\" |> from_string!(:iso_8859_1)\n    iex> to_string(iso, :ascii, use_utf_replacement())\n    {:ok, \"Hello ���!\", 3}","ref":"Codepagex.html#use_utf_replacement/0-examples"},{"type":"type","title":"Codepagex.encoding/0","doc":"","ref":"Codepagex.html#t:encoding/0"},{"type":"type","title":"Codepagex.from_s_missing_inner/0","doc":"","ref":"Codepagex.html#t:from_s_missing_inner/0"},{"type":"type","title":"Codepagex.from_s_missing_outer/0","doc":"","ref":"Codepagex.html#t:from_s_missing_outer/0"},{"type":"type","title":"Codepagex.to_s_missing_inner/0","doc":"","ref":"Codepagex.html#t:to_s_missing_inner/0"},{"type":"type","title":"Codepagex.to_s_missing_outer/0","doc":"","ref":"Codepagex.html#t:to_s_missing_outer/0"},{"type":"task","title":"mix codepagex.unicode","doc":"This mix task will download the source mapping files from http://unicode.org\n\n  The files should already be present in the git repository, but if necessary,\n  this mix task may be run to refresh them.\n\n  `wget` is assumed to be installed.\n\n  Some files are left out of the download process altogether, while others are\n  filtered by `.gitignore`, depending on what seemed most practical.\n\n  Only use this when developing for Codepagex itself.","ref":"Mix.Tasks.Codepagex.Unicode.html"},{"type":"task","title":"Synopsis - mix codepagex.unicode","doc":"$ mix codepagex.unicode","ref":"Mix.Tasks.Codepagex.Unicode.html#module-synopsis"},{"type":"function","title":"Mix.Tasks.Codepagex.Unicode.run/1","doc":"","ref":"Mix.Tasks.Codepagex.Unicode.html#run/1"},{"type":"exception","title":"Codepagex.Error","doc":"An error returned by Codepagex","ref":"Codepagex.Error.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}